clear all
set more off

cd "O:\mentalhealth\data\"

* kids health
forvalues i=2006/2020 {
	use if age <= 50 using "kurhgp_new_`i'.dta", clear
	drop if lopenr == ""
	ge gp = TypePraksis == "Fastlege"  | TypePraksis == "Fastlønnet" 
	ge er = TypePraksis == "Legevakt"  | TypePraksis == "Legevakt kommunal" 
	
	gen adhd  = regexm(diagnose , "P81")  if TypeDiag == "ICPC-2"
	gen eating = (regexm(diagnose , "P11")|regexm(diagnose , "P86")) if TypeDiag == "ICPC-2"
	drop other_psy
	ge other_psy =  psych == 1 & depression!=1 & anxiety!=1 & substance !=1  & adhd!=1 & eating!=1 & TypeDiag == "ICPC-2"
	ge non_psy = psych != 1 if TypeDiag == "ICPC-2"
	
	ge asthma_allergies =  (regexm(diagnose , "R95")|regexm(diagnose , "R96")|regexm(diagnose , "R97")) if TypeDiag == "ICPC-2"
	ge fractures = (regexm(diagnose , "L72")|regexm(diagnose , "L73")|regexm(diagnose , "L74")|regexm(diagnose , "L75")|regexm(diagnose , "L76")|regexm(diagnose , "L77")|regexm(diagnose , "L78")|regexm(diagnose , "L79")|regexm(diagnose , "L80")|regexm(diagnose , "L81")) if TypeDiag == "ICPC-2"
	
	keep age gp er simple_contact consult blood_test labtest non_psy psych  ps pd ///
			depression anxiety substance adhd eating other_psy diag_A diag_B diag_D diag_E ///
			diag_F diag_H diag_K diag_L diag_N diag_P ///
			diag_R diag_S diag_T diag_U asthma_allergies fractures ///
			lopenr year month KUHRDato
	qui compress
	save "khurh_annual_kids`i'.dta", replace
}


use "khurh_annual_kids2006.dta", clear
forvalues i=2007/2020 {
	append using "khurh_annual_kids`i'.dta"
}
keep if age < 30
ge dep_anx = depression == 1 | anxiety == 1
keep if gp==1 | er == 1
ge total = 1 
collapse (sum) total gp er simple_contact consult blood_test labtest non_psy psych ps pd ///
			depression anxiety substance adhd eating other_psy diag_A diag_B diag_D diag_E ///
			diag_F diag_H diag_K diag_L diag_N diag_P asthma_allergies fractures dep_anx ///
			diag_R diag_S diag_T diag_U, by(lopenr year) 		
save khurh_annual_kids, replace

for num 2006/2020: erase "khurh_annual_kidsX.dta"

* get parents' data for table A7 
use "khurh_annual_kids2006.dta", clear
forvalues i=2007/2012 {
	append using "khurh_annual_kids`i'.dta"
}
keep if age <= 30
ge dep_anx = depression == 1 | anxiety == 1
keep if gp==1 | er == 1
ge total = 1 
collapse (sum) total gp er simple_contact consult blood_test labtest non_psy psych ps pd ///
			depression anxiety substance adhd eating other_psy diag_A diag_B diag_D diag_E ///
			diag_F diag_H diag_K diag_L diag_N diag_P asthma_allergies fractures dep_anx ///
			diag_R diag_S diag_T diag_U, by(lopenr year)
save khurh_annual_parents, replace


* prevalence graphs (fig A1, A2)
*for graph - parents mh
use khurh_annual_kids, clear
keep lopenr diag_P 
replace diag_P = 1 if diag_P >1 & diag_P!=.
collapse (max) diag_P, by(lopenr) 
rename diag_P par_diag_P
save tempmh, replace



use khurh_annual_kids, clear
keep if year <=2020
merge m:1 lopenr using background
drop diag_A diag_B diag_D diag_E diag_F diag_H diag_K diag_L diag_N diag_R diag_S diag_T diag_U  simple_contact consult blood_test labtest  total gp er depression anxiety substance adhd eating other_psy 
foreach var in diag_P ps pd non_psy {
	replace `var' =0 if `var'==.
}
ge any_p = diag_P>0

rename lopenr ncpid
rename lopenr_mor lopenr
merge m:1 lopenr using edu_max, keep(1 3) nogen
rename temp eduy_m
merge m:1 lopenr using  tempmh, keep(1 3) nogen
rename par_diag_P mor_diag_P
rename lopenr lopenr_mor
rename lopenr_far lopenr
merge m:1 lopenr using edu_max, keep(1 3) nogen
rename temp eduy_f
merge m:1 lopenr using  tempmh, keep(1 3) nogen
rename par_diag_P far_diag_P
rename lopenr lopenr_far
rename ncpid lopenr

for var far_diag_P mor_diag_P: replace X = 0 if X==.
egen par_any_p = rmax(far_diag_P mor_diag_P)

* parental educ
foreach j in m f {	
	tostring eduy_`j', replace
	ge bu_1`j' = substr(eduy_`j',1,1)
	destring bu_1`j', replace
}
ge aux = inlist(bu_1m, 6, 7, 8) | inlist(bu_1f, 6, 7, 8)
bys lopenr: egen college_par = max(aux)
ge age = year-yob
keep if yob >= 1990
keep if age<= 26
drop aux 

ge male = sex == "1"
ge aux = any_p if male==1
bys age: egen any_pm = mean(aux)
drop aux 
ge aux = any_p if male==0
bys age: egen any_pg = mean(aux)
drop aux 

ge aux = any_p if college == 1
bys age: egen any_pc = mean(aux)
drop aux 
ge aux = any_p if college==0
bys age: egen any_pnc = mean(aux)
drop aux 

ge aux = any_p if par_any_p==1
bys age: egen any_pmh1 = mean(aux)
drop aux 
ge aux = any_p if par_any_p==0
bys age: egen any_pmh0 = mean(aux)
drop aux 



collapse any_p any_pg any_pm any_pc any_pnc any_pmh1 any_pmh0 , by(age)
label var any_p "All"
label var any_pg "Girls"
label var any_pm "Boys"
label var any_pc "Parents with college degree"
label var any_pnc "Parents without college degree"
label var any_pmh1 "Parents with MH"
label var any_pmh0 "Parents without MH"
line any_p any_pg any_pm age,  graphregion(fcolor(white) color(white)) ylabel(0(0.1)0.3)  lcolor(black red blue) lwidth(thick  thick thick)
gr export "../tables_oct/prevalence.pdf", as(pdf) replace

line any_pc any_pnc age,  graphregion(fcolor(white) color(white)) ylabel(0(0.1)0.3)  lcolor(red blue)  lwidth(thick thick)
gr export "../tables_oct/prevalence2.pdf", as(pdf) replace

line  any_pmh1 any_pmh0  age,  graphregion(fcolor(white) color(white)) ylabel(0(0.1)0.4)  lcolor(red blue)  lwidth(thick thick)
gr export "../tables_oct/prevalence3.pdf", as(pdf) replace




