clear all
capture clear
capture log close
capture program drop _all
cd "O:\mentalhealth\data\"
set more off
set maxvar 12000

global results "O:\mentalhealth\tables_may\"
/*
use  "S:\Project\DemoSos2\data2020\Befolkn\Demogr\faste_oppl", clear
gen  foreign = invkat!="A" if invkat!=""
rename (mor_lnr far_lnr kjoenn foedselsaar) (lopenr_mor lopenr_far sex yob) 
keep yob foreign lopenr
duplicates drop
save yob, replace
*/
*------------------------------------------------------------------------------*
** SOMATIC **
*------------------------------------------------------------------------------*
foreach num of numlist  2008/2020 {
	use  lopenr aar kjonn alder hoved1 innuke if alder >= 13 & alder<=18 using "S:/Project/DemoSos2/data2020/NPR/SOM/somatikk`num'.dta", clear
	drop if lopenr == ""
	
	gen npr_mental = (regexm(hoved1, "F")) | (regexm(hoved1, "F")) 
	
	rename aar year
	ge week_npr = yw(year,innuke)
	format week_npr %tw	
	
	duplicates drop
	save "mental_npr`num'.dta", replace
}

use mental_npr2008.dta, clear
for num 2009/2020: append using "mental_nprX.dta"
keep if npr_mental ==1
save mental_npr_all, replace
collapse (min) week_npr, by(lopenr)
duplicates drop
save mental_npr, replace


for num 2008/2020: erase "mental_nprX.dta"


*------------------------------------------------------------------------------*
* primary care
*------------------------------------------------------------------------------*
forvalues i = 2008/2020 { 
	use  lopenr Alder kjonn TypeDiag Diagnose KUHRDato if Alder >= 13 & Alder<=18 using "S:/Project/DemoSos2/data2020/KUHR2021/KUHR`i'", clear
	drop if lopenr == ""

	gen mental = regexm(Diagnose , "P") if TypeDiag == "ICPC-2"
	replace mental = 1 if (regexm(Diagnose , "P")) & TypeDiag=="ICD-10"
	
	gen week_kuhr = wofd(KUHRDato)
	format week_kuhr %tw

	gen year=`i'
	save "_diag`i'.dta", replace
}

use "_diag2008.dta", clear
for num 2009/2020: append using "_diagX.dta"
keep if mental ==1
collapse (min) week_kuhr, by(lopenr)
duplicates drop
save mental_khur, replace

for num 2008/2020: erase "_diagX.dta"

*------------------------------------------------------------------------------*
** AVTALESPESIALISTER - PSYKISK HELSE **
*------------------------------------------------------------------------------*
use if alder >= 13 & alder<=18 using "S:\Project\DemoSos2\data2020\NPR\AVTSP_PSYK\avtspes_psyk.dta", clear
drop if lopenr == ""

* Diagnoses:
ge icd_l = substr(hoved1,1,1)
ge icd_l2 = substr(hoved2,1,1)

ge asp_mental = icd_l =="F"|icd_l2 == "F"
gen asp_psyk = 1
rename aar year

ge week_asp = yw(year,innuke)
format week_asp %tw	

keep lopenr asp_mental  asp_psyk lopenr year week*

keep if asp_psyk == 1
collapse (min) week_asp, by(lopenr)
duplicates drop


save "psyk.dta", replace

*------------------------------------------------------------------------------*
															** REHABILITERING **
*------------------------------------------------------------------------------*
use if alder >= 13 & alder<=18 using "S:\Project\DemoSos2\data2020\NPR\TSB\rus_beh.dta", clear
drop if lopenr == ""

* Diagnoses:
ge icd_l = substr(hoved1, 1,1)
ge icd_l2 = substr(hoved2, 1,1)

replace icd_l = "E" if icd_l =="e" 
replace icd_l = "F" if icd_l =="f" 
replace icd_l = "G" if icd_l =="g" 
replace icd_l = "I" if icd_l =="i" 
replace icd_l = "J" if icd_l =="j" 
replace icd_l = "K" if icd_l =="k" 
replace icd_l = "L" if icd_l =="l" 
replace icd_l = "M" if icd_l =="m" 
replace icd_l = "N" if icd_l =="n" 
replace icd_l = "Q" if icd_l =="q" 
replace icd_l = "R" if icd_l =="r" 
replace icd_l = "S" if icd_l =="s" 
replace icd_l = "T" if icd_l =="t" 
replace icd_l = "Z" if icd_l =="z" 


ge npr_mental_rehab = 1 if (icd_l=="F"|icd_l2=="F")
* Dummy = 1 if in this register
ge npr_rehab = 1

rename aar year
ge week_npr_rehab = yw(year,innuke)
format week_npr_rehab  %tw	

keep lopenr week* npr_mental_rehab npr_rehab lopenr year

keep if npr_rehab == 1
collapse (min) week_npr_rehab, by(lopenr)
duplicates drop

save "npr_rehab.dta", replace ///2009-2020



*------------------------------------------------------------------------------*
															** psyk **
*------------------------------------------------------------------------------*
use if alder >= 13 & alder<=18 using "S:\Project\DemoSos2\data2020\NPR\PSYK_V\psyk_voksne.dta" , clear
drop if lopenr == ""

* Diagnoses:
ge icd_l = substr(hoved1, 1,1)
ge icd_l2 = substr(hoved2, 1,1)
replace icd_l = "E" if icd_l =="e" 
replace icd_l = "F" if icd_l =="f" 
replace icd_l = "G" if icd_l =="g" 
replace icd_l = "I" if icd_l =="i" 
replace icd_l = "J" if icd_l =="j" 
replace icd_l = "K" if icd_l =="k" 
replace icd_l = "L" if icd_l =="l" 
replace icd_l = "M" if icd_l =="m" 
replace icd_l = "N" if icd_l =="n" 
replace icd_l = "Q" if icd_l =="q" 
replace icd_l = "R" if icd_l =="r" 
replace icd_l = "S" if icd_l =="s" 
replace icd_l = "T" if icd_l =="t" 
replace icd_l = "Z" if icd_l =="z" 


ge psyk_v= 1 
rename aar year

ge week_psyk_v = yw(year,innuke)
format week_psyk_v  %tw	

keep lopenr week* psyk_v lopenr year

keep if psyk_v == 1
collapse (min) week_psyk_v, by(lopenr)
duplicates drop

save "bup.dta", replace

*------------------------------------------------------------------------------*
* compare timing of first diagnosis in primary vs specialist care
*------------------------------------------------------------------------------*
use mental_khur, clear
ge khur = 1
merge 1:1 lopenr using mental_npr, nogen
merge 1:1 lopenr using psyk,  nogen
merge 1:1 lopenr using npr_rehab,  nogen
merge 1:1 lopenr using bup,  nogen
replace khur = 0 if khur ==.

egen min = rmin(week_kuhr week_npr week_asp week_npr_rehab week_psyk_v)
ge d = min ==week_kuhr
tab d
-
/*
<= 18
          d |      Freq.     Percent        Cum.
------------+-----------------------------------
          0 |     41,066        8.60        8.60
          1 |    436,267       91.40      100.00
------------+-----------------------------------
      Total |    477,333      100.00
	  
13-18
 tab d

          d |      Freq.     Percent        Cum.
------------+-----------------------------------
          0 |     25,751        8.98        8.98
          1 |    260,957       91.02      100.00
------------+-----------------------------------
      Total |    286,708      100.00
	  
*/

keep if d==0
merge 1:m lopenr using mental_npr_all
keep if _m==3
ge icd10 = substr(hoved1,1,3)

* most common 13-18
* 19% F84 pervasive dev disorders
* 12% F70 mild mental retardation 
* 9% F98
* 5% F50 Eating disorders
* 5% F43 reaction to servere stress
* 4% F10 Mental and behavior disorders due to use of alcohol




