
clear all
capture clear
capture log close
capture program drop _all
cd "O:\mentalhealth\data\"
set more off
set maxvar 12000

global results "O:\mentalhealth\tables_rep\"

log using "O:\mentalhealth\tables_rep\table8a.log", tex replace


*----------------------------------------------------------------------------
** information on medical leave
*----------------------------------------------------------------------------
use sl_ind, clear
keep if year >=2006 & year<= 2008
keep lopenr year pinc days_sl_ diagslP 
merge m:1 lopenr using "S:\Project\DemoSos2\data2020\Befolkn\Demogr\faste_oppl", keepusing(foedselsaar) 
rename _merge merge1
rename foedselsaar _yob
drop if _yob <= 1970
fillin lopenr year  

keep if year >=2006 & year<= 2008
bys lopenr: egen yob=max(_yob)
drop _yob
ge age = year-yob
keep if age >=25 & age <= 30
drop age yob _fillin merge1
ge not_elig = pinc==0 | pinc==.
save sl_temp, replace


*----------------------------------------------------------------------------
** information from GP
*---------------------------------------------------------------------------
forvalues i=2006/2008 {
	use "kurhgp_new_`i'.dta", clear
	drop if lopenr == ""
	ge gp = TypePraksis == "Fastlege"  | TypePraksis == "Fastlønnet" 
	ge er = TypePraksis == "Legevakt"  | TypePraksis == "Legevakt kommunal" 
	keep if gp==1|er==1
	ge sl2 = (regexm(Takst, "L1")|regexm(Takst, "L4")|regexm(Takst, "L8")|regexm(Takst, "L9")) 
	ge total = 1

	collapse (sum) gp total (max) diag_P sl2 pd ps, by(lopenr year)
	rename pd pd_k 
	rename ps ps_k
	duplicates drop
	qui compress
	save "k`i'.dta", replace
}

*---------------------------------------------------
* indiv that work and dont get sl & indiv not elig
*---------------------------------------------------
use "k2006.dta", clear
append using "k2007.dta"
append using "k2008.dta"
merge 1:m lopenr year using sl_temp
drop _m
merge m:1 lopenr using "S:\Project\DemoSos2\data2020\Befolkn\Demogr\faste_oppl", keepusing(foedselsaar kjoenn invkat) 
rename _merge merge1
rename foedselsaar _yob
drop if _yob <= 1970
fillin lopenr year  
keep if year >=2006 & year<= 2008
bys lopenr: egen yob=max(_yob)
drop _yob
ge age = year-yob
keep if age >=25 & age <= 30
bys lopenr: egen aux = mode(invkat)
gen  foreign = aux!="A" if aux!=""
drop aux
destring  kjoenn, replace
bys lopenr: egen aux = max(kjoenn)
ge male = aux==1
for var total diag_P sl2 ps_k pd_k: replace X = 0 if X ==.
for var diag_P sl2 ps_k pd_k: replace X = 1 if X > 0 & X !=.

ge any_sl = days_sl_ > 0 if not_elig!=1
ge any_slp = diagslP > 0  if not_elig!=1
duplicates drop

merge m:1 lopenr using edu_max, keep(3) nogen
tostring temp, replace
ge bu_1 = substr(temp,1,1)
destring bu_1, replace
ge college = inlist(bu_1, 6, 7, 8) 

tab any_slp diag_P, m
tab1 any_slp ps pd if diag_P==1, m
ge y = pinc/100000
ge y2 = y^2
ge gp2 = gp^2
ge total2=total^2
ge miss = any_slp==0&diag_P==1 if any_slp!=. | diag_P!=.

ge inslp = any_slp==1 if diag_P==1


foreach var in male age  total y foreign college  {
	eststo c`var': reg `var' not_elig i.year , robust
	su `var' if e(sample), d
	estadd r(mean): c`var'
	est store c`var'
	
	eststo d`var': reg `var' inslp i.year if not_elig==0, robust
	su `var' if e(sample), d
	estadd r(mean): d`var'
	est store d`var'
	
}

su not_elig miss inslp


esttab cmale cage ctotal cy cforeign ccollege using "$results\table8a.tex", replace booktabs fragment nolines noconstant b(3) se(3) star(* 0.1 ** 0.05 *** 0.01) stats(mean N, fmt(%9.3g))  label
esttab dmale dage dtotal dy dforeign dcollege using "$results\table8a.tex", append booktabs fragment nolines noconstant b(3) se(3) star(* 0.1 ** 0.05 *** 0.01) stats(mean N, fmt(%9.3g))  label


* do indiv with MH problems that take vs. not take sl have more/less severe problems?
bys any_slp: su ps pd if diag_P==1 ///similar

keep if year==2008
* get the hospital data
merge 1:1 lopenr year using npr_sample, keep(1 3) nogen keepusing(npr_mental)
replace npr_mental =0 if npr_mental==. & year >= 2008 & year <= 2020

* get psyk treat
merge 1:1 lopenr year using psyk.dta, keep(1 3) nogen keepusing(asp_mental asp_psyk)
foreach var in asp_mental asp_psyk {
		replace `var' =0 if `var'==. & year >= 2008 & year <= 2020
}

ge sec_mental = npr_mental + asp_mental + asp_psyk
ge dsec_mental = sec_mental >0 if year>=2008 & year <= 2020
bys any_slp: su ps pd dsec_mental if diag_P==1 

log close
