clear all
capture clear
capture log close
capture program drop _all
set maxvar 100000
set max_memory 120g
cd "O:\mentalhealth\data\"
set more off

global results "O:\mentalhealth\tables_rep\"

log using "O:\mentalhealth\tables_rep\pol_reg.log", tex replace

********************************************************************************
use if yr== 2005 using Munic, clear
keep Pop_total landarea_1997 popdensity_1997 unrestr_1997 educHigh_1997 educMed_1997 educLow_1997 MDpc CWpc SNpc komnr 
rename komnr bokomm
duplicates drop

ge treat_c = bokomm==	221 | bokomm== 532 | bokomm== 230 | bokomm== 231 | bokomm==	529 | bokomm==	906 | bokomm==	602 | bokomm==	1002 ///
	| bokomm==	1014 | bokomm==	1247 | bokomm==	1201 | bokomm==	1219 | bokomm==	1246 | bokomm==	1432 | bokomm==	1106 | bokomm==	1102 /// 
	| bokomm==	1121 | bokomm==	1742 | bokomm==	1718 | bokomm==	1703 | bokomm==	1702 | bokomm==	1601 | bokomm==	1804 | bokomm==	1841 /// 
	| bokomm==	1942 | bokomm==	1902

replace Pop_total=Pop_total/1000
replace landarea_1997 = landarea_1997/1000
replace unrestr_1997=unrestr_1997/100

psmatch2 treat, mahalanobis(Pop_total landarea_1997 unrestr_1997 educHigh_1997 educMed_1997 educLow_1997 MDpc CWpc) 
for var _treated _support _weight: rename X X_r

lab var Pop_total 		"Total Population"
lab var landarea_1997 	"Land Area sqKm" 
lab var unrestr_1997  	"Municipality income"
lab var educHigh_1997 	"Share with University Degree"
lab var educMed_1997 	"Share with High School"
lab var educLow_1997 	"Share with Compulsory Education"
lab var CWpc 		"Man-years in child welfare"
lab var MDpc 		"Doctors in munic per 1,000 inhab." 

local covs : display "landarea_1997 unrestr_1997 educHigh_1997 educMed_1997 educLow_1997 MDpc CWpc"
					 					 
local r : word count `covs'
mat A = J(1,5,.)
local i = 1
local rown ""


foreach var of local covs {
	
	local vlab : variable label `var'
	local rown `"`rown' "`vlab'""'
		
	mat B = J(1,`=colsof(A)',.)
	
	qui sum `var' if treat_c == 1
	local b1: display %5.4f r(mean)
	qui sum `var' if treat_c == 0
	local b0: display %5.4f r(mean)
	qui sum `var' if treat_c == 0  & _weight!=.
	local b0m: display %5.4f r(mean)
	qui reg `var' treat_c
	local t = _b[treat_c] / _se[treat_c]
	qui reg `var' treat_c if _weight_r!=. 
	local t2 = _b[treat_c] / _se[treat_c]			

	mat B[1,1] 		= `b1'
	mat B[1,2] 		= `b0'
	mat B[1,3] 		= `b0m'
	mat B[1,4] 		= `t'
	mat B[1,5] 		= `t2'
	mat list B
	mat A= [A\B]
	mat list A
	
	local i = `i' + 1
}


mat D = A
mat rown D = "" `rown'	
mat coln D = "Treated" "Not Treated" "Not Treated" "\(t\)-stat" "\(t\)-stat-rew"
mat list D	
	
esttab matrix(D, fmt(3)) using "$results/table18a.tex", replace booktabs fragment nomtitles subst(.\\ "\\")
duplicates drop

* MAPS
** merge map data
preserve
* keep only matched municipalities 
keep if _weight!=.
ge id = bokomm
merge 1:m id using "Norwegian Maps Authority/MAP_data.dta", update
drop _merge
spmap   treat_c using "Norwegian Maps Authority/MAP_coord.dta", id(MAP_id) ///
	ndfcolor(white) ndocolor(black) fcolor(blue red) legend(order(3 "Treat" 2 "Control")) cln(4) legend(pos(11)) legstyle(2) 
graph export "$results/fig3a.pdf", replace   
restore
tempfile kom
save `kom'


use  sl_ind, clear
keep if year >=2000 & year <= 2010
ge age = year-yob
*keep if age>= 20 & age <=45
collapse (max) diagslP, by(lopenr)
preserve
rename diagslP ps_mom
rename lopenr lopenr_mor
tempfile slmor
save `slmor'
restore

rename diagslP ps_dad
rename lopenr lopenr_far
tempfile slfar
save `slfar'

use edu_max, clear
tostring temp, replace
ge bu_1m = substr(temp,1,1)
destring bu_1m, replace
drop temp
rename lopenr lopenr_mor
tempfile edumor
save `edumor'


use edu_max, clear
tostring temp, replace
ge bu_1f = substr(temp,1,1)
destring bu_1f, replace
drop temp
rename lopenr lopenr_far
tempfile edufar
save `edufar'

********************************************************************************
use sample_final_x5, clear
drop *_lnr_spouse *cous* *r_sib*_sp_sib
merge m:1 bokomm using `kom'
keep if _m==3
drop _m
egen gr = group(bokomm)
su gr

merge m:1  lopenr_mor using `slmor'
keep if _m!=2
drop _m
merge m:1 lopenr_far using `slfar'
keep if _m!=2
drop _m
egen both = rmax(ps_mom ps_dad)
replace both = 1 if both > 1 & both!=.

drop bu_1m bu_1f
merge m:1  lopenr_mor using `edumor'
keep if _m!=2
drop _m
merge m:1 lopenr_far using `edufar'
keep if _m!=2
drop _m

ge age2011 = 2011-yob
ge age2007 = 2007-yob
g d = 6-age2007 
replace d = 0 if age2007 >= 7 
replace d = 4 if d >= 4 & d !=.
ge t = d > 1 if d!=. 

keep if age2007 <=14
keep if yob>=1996 & yob <= 2005
tab age2007, ge(dage2007_)


tab yob, ge(yob_)
foreach num of numlist 1/10 {
	for var MDpc CWpc Pop_total  SNpc: ge X_yob`num' = X*yob_`num'
}

global fullcontrol "vekt i.paritet_5 male i.yob i.bu_1m i.bu_1f i.age_mbirth i.age_fbirth"
global fullcontrolb "i.paritet_5 male i.yob i.bu_1m i.bu_1f i.age_mbirth i.age_fbirth"
global trend "MDpc_yob*  CWpc_yob*  Pop_total_yob*   SNpc_yob* "


********************************************************************************
* TABLES
********************************************************************************
foreach var in cdiag_P  {
	foreach tt in t d  {
		eststo `var'`tt'1: xi: areg  `var' _treated_r##c.`tt'##both $fullcontrol if _weight_r!=., a(bokomm) cl(bokomm)
	
		eststo `var'`tt'2: xi: areg `var' _treated_r##c.`tt'##both $fullcontrol if  college_par==1 & _weight_r!=., a(bokomm) cl(bokomm)
		
		eststo `var'`tt'3: xi: areg `var' _treated_r##c.`tt'##both $fullcontrol if  college_par==0 & _weight_r!=., a(bokomm) cl(bokomm)
		
		eststo `var'`tt'4: xi: areg  `var' _treated_r##c.`tt'##both $fullcontrol if  male==1 & _weight_r!=., a(bokomm) cl(bokomm)
		
		eststo `var'`tt'5: xi: areg  `var' _treated_r##c.`tt'##both $fullcontrol if  male==0 & _weight_r!=., a(bokomm) cl(bokomm)
	}
}

local tt "t"
#delimit ; 
	esttab cdiag_P`tt'1 cdiag_P`tt'2 cdiag_P`tt'3 cdiag_P`tt'4 cdiag_P`tt'5
	using "$results/table9.tex", replace
	booktabs fragment 
	noobs nolines
	keep( 1._treated_r#1.both#c.`tt' 1.both)
	b(3) se(3) star(* 0.1 ** 0.05 *** 0.01)
	mtitle("All" "College" "No college" "Males" "Females")
	stats(N, fmt(%9.3g)) 
	label
	;
#delimit cr	

local tt "d"
#delimit ; 
	esttab cdiag_P`tt'1 cdiag_P`tt'2 cdiag_P`tt'3 cdiag_P`tt'4 cdiag_P`tt'5
	using "$results/table9.tex", append
	booktabs fragment 
	noobs nolines
	keep( 1._treated_r#1.both#c.`tt' 1.both)
	b(3) se(3) star(* 0.1 ** 0.05 *** 0.01)
	mtitle("All" "College" "No college" "Males" "Females")
	stats(N, fmt(%9.3g)) 
	label
	;
#delimit cr	
est clear

foreach var in cdiag_P   {
	foreach tt in t {
		eststo `var'`tt'1: xi: areg  `var' _treated_r##c.`tt'##both $fullcontrol $trend if _weight_r!=., a(bokomm) cl(bokomm)
		
		eststo `var'`tt'2: xi: areg  `var' _treated_r##c.`tt'##both $fullcontrol $trend if  college_par==1 & _weight_r!=., a(bokomm) cl(bokomm)
		
		eststo `var'`tt'3: xi: areg  `var' _treated_r##c.`tt'##both $fullcontrol $trend if  college_par==0 & _weight_r!=., a(bokomm) cl(bokomm)
		
		eststo `var'`tt'4: xi: areg  `var' _treated_r##c.`tt'##both $fullcontrol $trend if  male==1 & _weight_r!=., a(bokomm) cl(bokomm)
		
		eststo `var'`tt'5: xi: areg  `var' _treated_r##c.`tt'##both $fullcontrol $trend if  male==0 & _weight_r!=., a(bokomm) cl(bokomm)
	}
}
local tt "t"
#delimit ; 
	esttab cdiag_P`tt'1 cdiag_P`tt'2 cdiag_P`tt'3 cdiag_P`tt'4 cdiag_P`tt'5
	using "$results/table9.tex", append
	booktabs fragment 
	noobs nolines
	keep( 1._treated_r#1.both#c.`tt' 1.both)
	b(3) se(3) star(* 0.1 ** 0.05 *** 0.01)
	mtitle("All" "College" "No college" "Males" "Females")
	stats(N, fmt(%9.3g)) 
	label
	;
#delimit cr	
eststo clear

********************************************************************************
* GRAPH
********************************************************************************

for num 1/10: ge _t_dage2007_X_both = _treated_r*dage2007_X*both  
for num 1/10: ge _t_dage2007_X = _treated_r*dage2007_X 
ge _t_both = _treated_r*both


local var "diag_P"
preserve
ge b = .
ge ub = .
ge lb = .

ge b2 = .
ge ub2 = .
ge lb2 = .

xi: areg  cdiag_P _t_dage2007_1_both-_t_dage2007_5_both _t_dage2007_7_both-_t_dage2007_10_both ///
_treated_r dage2007_* both  _t_dage2007_1-_t_dage2007_10 _t_both $fullcontrol if _weight_r!=., a(bokomm) cl(bokomm)

replace b = 0 if dage2007_6== 1

foreach j in 1 2 3 4 5 7 8 9 10  {
	replace b = _b[_t_dage2007_`j'_both] if dage2007_`j' == 1 &  _weight_r!=.
	replace ub = _b[_t_dage2007_`j'_both]+1.96*_se[_t_dage2007_`j'_both] if dage2007_`j' == 1 &  _weight_r!=.
	replace lb = _b[_t_dage2007_`j'_both]-1.96*_se[_t_dage2007_`j'_both] if dage2007_`j' == 1 &  _weight_r!=.
}

collapse b ub lb b2 ub2 lb2, by(age2007)

twoway scatter b age2007, c(l) lpattern(solid) msymbol(o) mc(black) lcolor(black) || ///
	rcap (ub lb) age2007, c(l) mcolor(gs10) lcolor(gs10) ///
	ytitle("Estimated effect ({&beta})") legend(off) yline(0,lc(black) lp(dot)) ///
	graphregion(fcolor(white) color(white)) xtitle("Age in 2007", size(medsmall)) ///
	scale(*.9) ysize(4) xsize(7) xline(7, lp(dash) lc(maroon)) xlabel(2(1)11)
gr export "$results/fig1.pdf", as(pdf) replace  

restore



********************************************************************************
* placebo
********************************************************************************
ge lowb = vekt < 2500 if vekt!=.


local tt "t"
foreach var in vekt lowb svlen apgar5 apgar1 asthma_allergies fractures diag_A diag_R diag_L {
	eststo `var': xi: areg  `var' _treated_r##c.`tt'##both $fullcontrolb if _weight_r!=., a(bokomm) cl(bokomm)		
	su `var' if e(sample), d
	estadd r(mean): `var'
	est store `var'
}
#delimit ; 
esttab vekt lowb svlen apgar5 apgar1 asthma_allergies fractures diag_A diag_R diag_L
using "$results/table19a.tex", replace
booktabs fragment 
noobs nolines
keep( 1._treated_r#1.both#c.`tt' 1.both)
b(3) se(3) star(* 0.1 ** 0.05 *** 0.01)
mtitle(vekt lowb svlen apgar5 apgar1 asthma_allergies fractures diag_A diag_R diag_L)
stats(mean N, fmt(%9.3g)) 
label
;
#delimit cr	
eststo clear

log close
