clear all
capture clear
capture log close
capture program drop _all
cd "O:\mentalhealth\data\"
set more off

//Master data for the family links	
use lopenr mor_lnr far_lnr using "S:\Project\DemoSos2\data2020\Befolkn\Demogr\faste_oppl", clear
compress
save data_dynastic_id, replace

//Working sample 
use lopenr mor_lnr far_lnr foedselsaar using "S:\Project\DemoSos2\data2020\Befolkn\Demogr\faste_oppl", clear

//Sample restrictions TBC
keep if foedselsaar >= 1985 & foedselsaar <= 2010
keep if !missing(mor_lnr) & !missing(far_lnr)

compress
save working_sample_children, replace


********************************************************************************
//GP ids 
********************************************************************************
foreach p in mor far {
	use working_sample_children, clear
	
	keep `p'_lnr //parents
	drop if missing(`p'_lnr)
	rename `p'_lnr lopenr
	duplicates drop
	
	merge 1:1 lopenr using data_dynastic_id.dta, keep(1 3) nogen keepusing(mor_lnr far_lnr)
	
	rename mor_lnr `p'mor_lnr //mormor = mother's mother; farmor = father's mother
	rename far_lnr `p'far_lnr //morfar = mother's father; farfar = father's father
	
	rename lopenr `p'_lnr
	
	keep `p'_lnr `p'mor_lnr `p'far_lnr
	
	merge 1:m `p'_lnr using working_sample_children, keep(2 3) nogen
	qui compress
	save working_sample_children, replace
}

********************************************************************************
// Great-grandparents 
********************************************************************************
foreach p in mormor morfar farmor farfar {
	use working_sample_children, clear
	
	keep `p'_lnr //parents
	drop if missing(`p'_lnr)
	rename `p'_lnr lopenr
	duplicates drop
	
	merge 1:1 lopenr using data_dynastic_id.dta, keep(1 3) nogen keepusing(mor_lnr far_lnr)
	
	rename mor_lnr `p'mor_lnr //mormormor = mother of the grandmother from the mother side; morfarmor = mother of the grandfather from the mother side; farmormor = mother of the grandmother from the father side; farfarmor = mother of the grandfather from the father side
	rename far_lnr `p'far_lnr //mormorfar = father of the grandmother from the mother side; morfarfar = father of the grandfather from the mother side; farmorfar = father of the grandmother from the father side; farfarfar = father of the grandfather from the father side
	
	rename lopenr `p'_lnr
	
	keep `p'_lnr `p'mor_lnr `p'far_lnr
	
	merge 1:m `p'_lnr using working_sample_children, keep(2 3) nogen
	qui compress
	save working_sample_children, replace
}

gen non_missing_ggp = 0
foreach GGP in mormormor mormorfar morfarmor morfarfar farmormor farmorfar farfarmor farfarfar {
	replace non_missing_ggp = 1 if !missing(`GGP')
}
tab non_missing_ggp,m 
drop non_missing_ggp

********************************************************************************
//Uncles/Aunts ids
********************************************************************************
foreach p in mor far {
	use working_sample_children, clear
	
	keep `p'mor_lnr // grand mothers + her children
	drop if missing(`p'mor_lnr) 
	rename `p'mor_lnr mor_lnr
	
	duplicates drop
	
	merge 1:m mor_lnr using data_dynastic_id.dta, keep(1 3) nogen keepusing(lopenr) 
	
	rename lopenr `p'sib
	bysort mor_lnr (`p'sib): gen j = _n
	
	sum j
	local max_j `r(max)'
	
	reshape wide `p'sib, i(mor_lnr) j(j)
	
	gen `p'mor_children = ""
	format `p'mor_children  %14s
	replace `p'mor_children = "," + `p'sib1 if `p'sib1!=""
	
	foreach i of numlist 2/`max_j' {
		replace `p'mor_children = `p'mor_children + "," + `p'sib`i' if `p'sib`i'!=""
	}
	
	rename mor_lnr `p'mor_lnr
	keep `p'mor_lnr `p'mor_children
	
	merge 1:m `p'mor_lnr using working_sample_children, keep(2 3) nogen
	save working_sample_children, replace
}
foreach p in mor far {
	use working_sample_children, clear
	
	keep `p'far_lnr // grand fathers + his children
	drop if missing(`p'far_lnr) 
	rename `p'far_lnr far_lnr
	
	duplicates drop
	
	merge 1:m far_lnr using data_dynastic_id.dta, keep(1 3) nogen keepusing(lopenr) 
	
	rename lopenr `p'sib
	bysort far_lnr (`p'sib): gen j = _n
	
	sum j
	local max_j `r(max)'
	
	reshape wide `p'sib, i(far_lnr) j(j)
	
	gen `p'far_children = ""
	format `p'far_children  %14s
	replace `p'far_children = "," + `p'sib1 if `p'sib1!=""
	
	foreach i of numlist 2/`max_j' {
		replace `p'far_children = `p'far_children + "," + `p'sib`i' if `p'sib`i'!=""
	}
	
	rename far_lnr `p'far_lnr
	keep `p'far_lnr `p'far_children
	
	merge 1:m `p'far_lnr using working_sample_children, keep(2 3) nogen
	qui compress
	save working_sample_children, replace
}
use working_sample_children, clear

gen mor_id = ""
replace mor_id = "," + mor_lnr if !missing(mor_lnr)

replace mormor_children = subinstr(mormor_children, mor_id, "", .) //removes the mother from the siblings
replace mormor_children = substr(mormor_children, 2, .)

replace morfar_children = subinstr(morfar_children, mor_id, "", .)
replace morfar_children = substr(morfar_children, 2, .)

gen mor_siblings = ""
replace mor_siblings = mormor_children + "," + morfar_children if !missing(mormor_children) & !missing(morfar_children)
replace mor_siblings = mormor_children if !missing(mormor_children) & missing(morfar_children)
replace mor_siblings = morfar_children if missing(mormor_children) & !missing(morfar_children)

gen far_id = ""
replace far_id = "," + far_lnr if !missing(far_lnr)

replace farmor_children = subinstr(farmor_children, far_id, "", .) //removes the father from the siblings
replace farmor_children = substr(farmor_children, 2, .)

replace farfar_children = subinstr(farfar_children, far_id, "", .)
replace farfar_children = substr(farfar_children, 2, .)

gen far_siblings = ""
replace far_siblings = farmor_children + "," + farfar_children if !missing(farmor_children) & !missing(farfar_children)
replace far_siblings = farmor_children if !missing(farmor_children) & missing(farfar_children)
replace far_siblings = farfar_children if missing(farmor_children) & !missing(farfar_children)

drop *children *id
qui compress
save working_sample_children, replace

foreach p in mor far {
	use working_sample_children, clear
	keep `p'_lnr `p'_siblings //remove duplicates from the siblings id
	split `p'_siblings, p(,)
	drop `p'_siblings
	duplicates drop
	reshape long `p'_siblings, i(`p'_lnr)
	drop _j
	duplicates drop
	drop if missing(`p'_siblings)
	bysort `p'_lnr (`p'_siblings): gen j = _n
	sum j
	local j `r(max)'
	replace `p'_siblings = "," + `p'_siblings if j != 1
	reshape wide `p'_siblings, i(`p'_lnr) j(j)
	gen `p'_siblings = `p'_siblings1
	drop `p'_siblings1
	foreach i of numlist 2/`j' {
		replace `p'_siblings = `p'_siblings + `p'_siblings`i' if !missing(`p'_siblings`i')
		drop `p'_siblings`i'
	}

	rename `p'_siblings `p'_siblings_clean
	merge 1:m `p'_lnr using working_sample_children, keep(2 3) nogen
	save working_sample_children, replace
}

drop mor_siblings far_siblings
rename mor_siblings_clean mor_siblings
rename far_siblings_clean far_siblings

order lopenr mor_lnr mor_siblings mormor_lnr morfar_lnr mormormor_lnr mormorfar_lnr morfarmor_lnr morfarfar_lnr far_lnr far_siblings farmor_lnr farfar_lnr farmormor_lnr farmorfar_lnr farfarmor_lnr farfarfar_lnr
compress
save working_sample_children, replace

